@@ -1,13 +1,16 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "Chan.h"
-#include "User.h"
+#include <znc/Chan.h>
+#include <znc/User.h>
+#include <znc/IRCNetwork.h>
+
+using std::vector;
 
 class CAutoCycleMod : public CModule {
 public:
@@ -79,7 +82,7 @@ public:
 			} else {
 				PutModule("You have no entries.");
 			}
-		} else if (sCommand.Equals("HELP")) {
+		} else {
 			CTable Table;
 			Table.AddColumn("Command");
 			Table.AddColumn("Description");
@@ -132,7 +135,7 @@ protected:
 
 		// Is that person us and we don't have op?
 		const CNick& pNick = Channel.GetNicks().begin()->second;
-		if (!pNick.HasPerm(CChan::Op) && pNick.GetNick().Equals(m_pUser->GetCurNick())) {
+		if (!pNick.HasPerm(CChan::Op) && pNick.GetNick().Equals(m_pNetwork->GetCurNick())) {
 			Channel.Cycle();
 			m_recentlyCycled.AddItem(Channel.GetName());
 		}
@@ -236,6 +239,8 @@ private:
 
 template<> void TModInfo<CAutoCycleMod>(CModInfo& Info) {
 	Info.SetWikiPage("autocycle");
+	Info.SetHasArgs(true);
+	Info.SetArgsHelpText("List of channel masks and channel masks with ! before them.");
 }
 
-MODULEDEFS(CAutoCycleMod, "Rejoins channels to gain Op if you're the only user left")
+USERMODULEDEFS(CAutoCycleMod, "Rejoins channels to gain Op if you're the only user left")
