@@ -1,13 +1,17 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "Chan.h"
-#include "User.h"
+#include <znc/IRCNetwork.h>
+#include <znc/Chan.h>
+
+using std::map;
+using std::set;
+using std::vector;
 
 class CAutoOpMod;
 
@@ -160,22 +164,7 @@ public:
 	virtual void OnJoin(const CNick& Nick, CChan& Channel) {
 		// If we have ops in this chan
 		if (Channel.HasPerm(CChan::Op)) {
-			for (map<CString, CAutoOpUser*>::iterator it = m_msUsers.begin(); it != m_msUsers.end(); ++it) {
-				// and the nick who joined is a valid user
-				if (it->second->HostMatches(Nick.GetHostMask()) && it->second->ChannelMatches(Channel.GetName())) {
-					if (it->second->GetUserKey().Equals("__NOKEY__")) {
-						PutIRC("MODE " + Channel.GetName() + " +o " + Nick.GetNick());
-					} else {
-						// then insert this nick into the queue, the timer does the rest
-						CString sNick = Nick.GetNick().AsLower();
-						if (m_msQueue.find(sNick) == m_msQueue.end()) {
-							m_msQueue[sNick] = "";
-						}
-					}
-
-					break;
-				}
-			}
+			CheckAutoOp(Nick, Channel);
 		}
 	}
 
@@ -213,6 +202,18 @@ public:
 		return HALTCORE;
 	}
 
+	virtual void OnOp(const CNick& OpNick, const CNick& Nick, CChan& Channel, bool bNoChange) {
+		if (Nick.GetNick() == m_pNetwork->GetIRCNick().GetNick()) {
+			const map<CString,CNick>& msNicks = Channel.GetNicks();
+
+			for (map<CString,CNick>::const_iterator it = msNicks.begin(); it != msNicks.end(); ++it) {
+				if (!it->second.HasPerm(CChan::Op)) {
+					CheckAutoOp(it->second, Channel);
+				}
+			}
+		}
+	}
+
 	virtual void OnModCommand(const CString& sLine) {
 		CString sCommand = sLine.Token(0).AsUpper();
 
@@ -309,6 +310,24 @@ public:
 		return NULL;
 	}
 
+	bool CheckAutoOp(const CNick& Nick, CChan& Channel) {
+		CAutoOpUser *pUser = FindUserByHost(Nick.GetHostMask(), Channel.GetName());
+
+		if (pUser) {
+			if (pUser->GetUserKey().Equals("__NOKEY__")) {
+				PutIRC("MODE " + Channel.GetName() + " +o " + Nick.GetNick());
+			} else {
+				// then insert this nick into the queue, the timer does the rest
+				CString sNick = Nick.GetNick().AsLower();
+				if (m_msQueue.find(sNick) == m_msQueue.end()) {
+					m_msQueue[sNick] = "";
+				}
+			}
+		}
+
+		return pUser;
+	}
+
 	void DelUser(const CString& sUser) {
 		map<CString, CAutoOpUser*>::iterator it = m_msUsers.find(sUser.AsLower());
 
@@ -345,7 +364,7 @@ public:
 
 			// First verify that the guy who challenged us matches a user's host
 			if (pUser->HostMatches(Nick.GetHostMask())) {
-				const vector<CChan*>& Chans = m_pUser->GetChans();
+				const vector<CChan*>& Chans = m_pNetwork->GetChans();
 				bMatchedHost = true;
 
 				// Also verify that they are opped in at least one of the user's chans
@@ -440,7 +459,7 @@ public:
 	}
 
 	void OpUser(const CNick& Nick, const CAutoOpUser& User) {
-		const vector<CChan*>& Chans = m_pUser->GetChans();
+		const vector<CChan*>& Chans = m_pNetwork->GetChans();
 
 		for (size_t a = 0; a < Chans.size(); a++) {
 			const CChan& Chan = *Chans[a];
@@ -467,4 +486,4 @@ template<> void TModInfo<CAutoOpMod>(CModInfo& Info) {
 	Info.SetWikiPage("autoop");
 }
 
-MODULEDEFS(CAutoOpMod, "Auto op the good guys")
+NETWORKMODULEDEFS(CAutoOpMod, "Auto op the good guys")
