@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -8,10 +8,10 @@
 
 #define REQUIRESSL
 
-#include "FileUtils.h"
-#include "User.h"
-#include "Modules.h"
-#include "IRCSock.h"
+#include <znc/FileUtils.h>
+#include <znc/User.h>
+#include <znc/Modules.h>
+#include <znc/IRCSock.h>
 
 class CCertMod : public CModule {
 public:
@@ -73,11 +73,11 @@ public:
 				fPemFile.Close();
 			}
 
-			WebSock.Redirect("/mods/cert/");
+			WebSock.Redirect(GetWebPath());
 			return true;
 		} else if (sPageName == "delete") {
 			CFile::Delete(PemFile());
-			WebSock.Redirect("/mods/cert/");
+			WebSock.Redirect(GetWebPath());
 			return true;
 		}
 
@@ -86,7 +86,8 @@ public:
 };
 
 template<> void TModInfo<CCertMod>(CModInfo& Info) {
+	Info.AddType(CModInfo::NetworkModule);
 	Info.SetWikiPage("cert");
 }
 
-MODULEDEFS(CCertMod, "Use a ssl certificate to connect to a server")
+USERMODULEDEFS(CCertMod, "Use a ssl certificate to connect to a server")
