@@ -1,32 +1,36 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "Chan.h"
-#include "User.h"
-#include "znc.h"
+#include <znc/Chan.h>
+#include <znc/User.h>
+#include <znc/IRCNetwork.h>
+#include <znc/znc.h>
+
+using std::vector;
 
 class CChanSaverMod : public CModule {
 public:
 	MODCONSTRUCTOR(CChanSaverMod) {
-		const vector<CChan*>& vChans = m_pUser->GetChans();
-		vector<CChan*>::const_iterator it = vChans.begin();
-		vector<CChan*>::const_iterator end = vChans.end();
-
 		m_bWriteConf = false;
 
-		for (; it != end; ++it) {
-			CChan *pChan = *it;
+		vector<CIRCNetwork*> vNetworks = pUser->GetNetworks();
+		for (vector<CIRCNetwork*>::iterator it = vNetworks.begin(); it != vNetworks.end(); ++it) {
+			const vector<CChan*>& vChans = (*it)->GetChans();
 
-			// If that channel isn't yet in the config,
-			// we'll have to add it...
-			if (!pChan->InConfig()) {
-				pChan->SetInConfig(true);
-				m_bWriteConf = true;
+			for (vector<CChan*>::const_iterator it2 = vChans.begin(); it2 != vChans.end(); ++it2) {
+				CChan *pChan = *it2;
+
+				// If that channel isn't yet in the config,
+				// we'll have to add it...
+				if (!pChan->InConfig()) {
+					pChan->SetInConfig(true);
+					m_bWriteConf = true;
+				}
 			}
 		}
 	}
@@ -55,14 +59,14 @@ public:
 	}
 
 	virtual void OnJoin(const CNick& Nick, CChan& Channel) {
-		if (Nick.GetNick() == m_pUser->GetIRCNick().GetNick()) {
+		if (Nick.GetNick() == m_pNetwork->GetIRCNick().GetNick()) {
 			Channel.SetInConfig(true);
 			CZNC::Get().WriteConfig();
 		}
 	}
 
 	virtual void OnPart(const CNick& Nick, CChan& Channel, const CString& sMessage) {
-		if (Nick.GetNick() == m_pUser->GetIRCNick().GetNick()) {
+		if (Nick.GetNick() == m_pNetwork->GetIRCNick().GetNick()) {
 			Channel.SetInConfig(false);
 			CZNC::Get().WriteConfig();
 		}
@@ -74,6 +78,7 @@ private:
 
 template<> void TModInfo<CChanSaverMod>(CModInfo& Info) {
 	Info.SetWikiPage("chansaver");
+	Info.AddType(CModInfo::NetworkModule);
 }
 
-MODULEDEFS(CChanSaverMod, "Keep config up-to-date when user joins/parts")
+USERMODULEDEFS(CChanSaverMod, "Keep config up-to-date when user joins/parts")
