@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -22,8 +22,9 @@
 //       It is strongly suggested that you enable SSL between znc and your client otherwise the encryption stops at znc and gets sent to your client in plain text.
 //
 
-#include "Chan.h"
-#include "User.h"
+#include <znc/Chan.h>
+#include <znc/User.h>
+#include <znc/IRCNetwork.h>
 
 #define REQUIRESSL	1
 
@@ -43,11 +44,11 @@ public:
 		MCString::iterator it = FindNV(sTarget.AsLower());
 
 		if (it != EndNV()) {
-			CChan* pChan = m_pUser->FindChan(sTarget);
+			CChan* pChan = m_pNetwork->FindChan(sTarget);
 			if (pChan) {
-				if (pChan->KeepBuffer())
-					pChan->AddBuffer(":\244" + m_pUser->GetIRCNick().GetNickMask() + " PRIVMSG " + sTarget + " :" + sMessage);
-				m_pUser->PutUser(":\244" + m_pUser->GetIRCNick().GetNickMask() + " PRIVMSG " + sTarget + " :" + sMessage, NULL, m_pClient);
+				if (!pChan->AutoClearChanBuffer())
+					pChan->AddBuffer(":\244" + _NAMEDFMT(m_pNetwork->GetIRCNick().GetNickMask()) + " PRIVMSG " + _NAMEDFMT(sTarget) + " :" + _NAMEDFMT(sMessage));
+				m_pUser->PutUser(":\244" + m_pNetwork->GetIRCNick().GetNickMask() + " PRIVMSG " + sTarget + " :" + sMessage, NULL, m_pClient);
 			}
 
 			CString sMsg = MakeIvec() + sMessage;
@@ -155,4 +156,4 @@ template<> void TModInfo<CCryptMod>(CModInfo& Info) {
 	Info.SetWikiPage("crypt");
 }
 
-MODULEDEFS(CCryptMod, "Encryption for channel/private messages")
+NETWORKMODULEDEFS(CCryptMod, "Encryption for channel/private messages")
