@@ -1,15 +1,16 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
+#include <znc/Modules.h>
+#include <znc/IRCNetwork.h>
+#include <znc/Chan.h>
 
-#include "Modules.h"
-#include "User.h"
-#include "Chan.h"
+using std::vector;
 
 class CKickClientOnIRCDisconnect: public CModule {
 public:
@@ -17,12 +18,12 @@ public:
 
 	void OnIRCDisconnected()
 	{
-		const vector<CChan*>& vChans = m_pUser->GetChans();
+		const vector<CChan*>& vChans = m_pNetwork->GetChans();
 
 		for(vector<CChan*>::const_iterator it = vChans.begin(); it != vChans.end(); ++it)
 		{
 			if((*it)->IsOn()) {
-				PutUser(":ZNC!znc@znc.in KICK " + (*it)->GetName() + " " + m_pUser->GetIRCNick().GetNick()
+				PutUser(":ZNC!znc@znc.in KICK " + (*it)->GetName() + " " + m_pNetwork->GetIRCNick().GetNick()
 					+ " :You have been disconnected from the IRC server");
 			}
 		}
@@ -33,4 +34,4 @@ template<> void TModInfo<CKickClientOnIRCDisconnect>(CModInfo& Info) {
 	Info.SetWikiPage("disconkick");
 }
 
-MODULEDEFS(CKickClientOnIRCDisconnect, "Kicks the client from all channels when the connection to the IRC server is lost")
+USERMODULEDEFS(CKickClientOnIRCDisconnect, "Kicks the client from all channels when the connection to the IRC server is lost")
