@@ -1,16 +1,16 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "znc.h"
+#include <znc/znc.h>
 
-class CFailToBanMod : public CGlobalModule {
+class CFailToBanMod : public CModule {
 public:
-	GLOBALMODCONSTRUCTOR(CFailToBanMod) {}
+	MODCONSTRUCTOR(CFailToBanMod) {}
 	virtual ~CFailToBanMod() {}
 
 	virtual bool OnLoad(const CString& sArgs, CString& sMessage) {
@@ -97,6 +97,8 @@ private:
 
 template<> void TModInfo<CFailToBanMod>(CModInfo& Info) {
 	Info.SetWikiPage("fail2ban");
+	Info.SetHasArgs(true);
+	Info.SetArgsHelpText("You might enter the time in minutes for the IP banning and the number of failed logins before any action is taken.");
 }
 
 GLOBALMODULEDEFS(CFailToBanMod, "Block IPs for some time after a failed login")
