@@ -1,23 +1,24 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "FileUtils.h"
-#include "IRCSock.h"
-#include "User.h"
-#include "znc.h"
+#include <znc/FileUtils.h>
+#include <znc/IRCSock.h>
+#include <znc/User.h>
+#include <znc/IRCNetwork.h>
+#include <znc/znc.h>
 
-class CIdentFileModule : public CGlobalModule {
+class CIdentFileModule : public CModule {
 	CString m_sOrigISpoof;
 	CFile* m_pISpoofLockFile;
 	CIRCSock *m_pIRCSock;
 
 public:
-	GLOBALMODCONSTRUCTOR(CIdentFileModule) {
+	MODCONSTRUCTOR(CIdentFileModule) {
 		AddHelpCommand();
 		AddCommand("GetFile",   static_cast<CModCommand::ModCmdFunc>(&CIdentFileModule::GetFile));
 		AddCommand("SetFile",   static_cast<CModCommand::ModCmdFunc>(&CIdentFileModule::SetFile),
@@ -59,7 +60,9 @@ public:
 		PutModule("m_pISpoofLockFile = " + CString((long long)m_pISpoofLockFile));
 		PutModule("m_pIRCSock = " + CString((long long)m_pIRCSock));
 		if (m_pIRCSock) {
-			PutModule("user = " + m_pIRCSock->GetUser()->GetUserName());
+			PutModule("user/network - " + m_pIRCSock->GetNetwork()->GetUser()->GetUserName() + "/" + m_pIRCSock->GetNetwork()->GetName());
+		} else {
+			PutModule("identfile is free");
 		}
 	}
 
@@ -71,6 +74,18 @@ public:
 		}
 	}
 
+	void SetIRCSock(CIRCSock *pIRCSock) {
+		if (m_pIRCSock) {
+			CZNC::Get().ResumeConnectQueue();
+		}
+
+		m_pIRCSock = pIRCSock;
+
+		if (m_pIRCSock) {
+			CZNC::Get().PauseConnectQueue();
+		}
+	}
+
 	bool WriteISpoof() {
 		if (m_pISpoofLockFile != NULL) {
 			return false;
@@ -94,7 +109,7 @@ public:
 			return false;
 		}
 
-		CString sData = m_pUser->ExpandString(GetNV("Format"));
+		CString sData = m_pNetwork->ExpandString(GetNV("Format"));
 
 		// If the format doesn't contain anything expandable, we'll
 		// assume this is an "old"-style format string.
@@ -102,7 +117,7 @@ public:
 			sData.Replace("%", m_pUser->GetIdent());
 		}
 
-		DEBUG("Writing [" + sData + "] to ident spoof file [" + m_pISpoofLockFile->GetLongName() + "] for user [" + m_pUser->GetUserName() + "]");
+		DEBUG("Writing [" + sData + "] to ident spoof file [" + m_pISpoofLockFile->GetLongName() + "] for user/network [" + m_pUser->GetUserName() + "/" + m_pNetwork->GetName() + "]");
 
 		m_pISpoofLockFile->Write(sData + "\n");
 
@@ -110,9 +125,10 @@ public:
 	}
 
 	void ReleaseISpoof() {
-		DEBUG("Releasing ident spoof for user [" + (m_pUser ? m_pUser->GetUserName() : "<no user>") + "]");
+		DEBUG("Releasing ident spoof for user/network [" + (m_pIRCSock ? m_pIRCSock->GetNetwork()->GetUser()->GetUserName() + "/" +
+				m_pIRCSock->GetNetwork()->GetName() : "<no user/network>") + "]");
 
-		m_pIRCSock = NULL;
+		SetIRCSock(NULL);
 
 		if (m_pISpoofLockFile != NULL) {
 			if (m_pISpoofLockFile->Seek(0) && m_pISpoofLockFile->Truncate()) {
@@ -142,7 +158,7 @@ public:
 	virtual EModRet OnIRCConnecting(CIRCSock *pIRCSock) {
 		if (m_pISpoofLockFile != NULL) {
 			DEBUG("Aborting connection, ident spoof lock file exists");
-			PutModule("Aborting connection, another user is currently connecting and using the ident spoof file");
+			PutModule("Aborting connection, another user or network is currently connecting and using the ident spoof file");
 			return HALTCORE;
 		}
 
@@ -152,12 +168,12 @@ public:
 			return HALTCORE;
 		}
 
-		m_pIRCSock = pIRCSock;
+		SetIRCSock(pIRCSock);
 		return CONTINUE;
 	}
 
 	virtual void OnIRCConnected() {
-		if (m_pIRCSock == m_pUser->GetIRCSock()) {
+		if (m_pIRCSock == m_pNetwork->GetIRCSock()) {
 			ReleaseISpoof();
 		}
 	}
@@ -169,7 +185,7 @@ public:
 	}
 
 	virtual void OnIRCDisconnected() {
-		if (m_pIRCSock == m_pUser->GetIRCSock()) {
+		if (m_pIRCSock == m_pNetwork->GetIRCSock()) {
 			ReleaseISpoof();
 		}
 	}
