@@ -1,13 +1,13 @@
 /*
- * Copyright (C) 2004-2009  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "Modules.h"
-#include "znc.h"
+#include <znc/Modules.h>
+#include <znc/znc.h>
 
 using std::map;
 
@@ -32,16 +32,16 @@ public:
 	virtual void ReadLine(const CString& sLine);
 private:
 protected:
-	CIMAPAuthMod*			m_pIMAPMod;
-	bool					m_bSentLogin;
-	bool					m_bSentReply;
-	CSmartPtr<CAuthBase>	m_spAuth;
+	CIMAPAuthMod*        m_pIMAPMod;
+	bool                 m_bSentLogin;
+	bool                 m_bSentReply;
+	CSmartPtr<CAuthBase> m_spAuth;
 };
 
 
-class CIMAPAuthMod : public CGlobalModule {
+class CIMAPAuthMod : public CModule {
 public:
-	GLOBALMODCONSTRUCTOR(CIMAPAuthMod) {
+	MODCONSTRUCTOR(CIMAPAuthMod) {
 		m_Cache.SetTTL(60000);
 		m_sServer = "localhost";
 		m_uPort = 143;
@@ -56,7 +56,7 @@ public:
 
 	virtual bool OnLoad(const CString& sArgs, CString& sMessage) {
 		if (sArgs.Trim_n().empty()) {
-			return true;	// use defaults
+			return true; // use defaults
 		}
 
 		m_sServer = sArgs.Token(0);
@@ -80,7 +80,7 @@ public:
 	virtual EModRet OnLoginAttempt(CSmartPtr<CAuthBase> Auth) {
 		CUser* pUser = CZNC::Get().FindUser(Auth->GetUsername());
 
-		if (!pUser) {	// @todo Will want to do some sort of && !m_bAllowCreate in the future
+		if (!pUser) { // @todo Will want to do some sort of && !m_bAllowCreate in the future
 			Auth->RefuseLogin("Invalid User - Halting IMAP Lookup");
 			return HALT;
 		}
@@ -109,13 +109,13 @@ public:
 	// !Getters
 private:
 	// Settings
-	CString				m_sServer;
-	unsigned short		m_uPort;
-	bool				m_bSSL;
-	CString				m_sUserFormat;
+	CString         m_sServer;
+	unsigned short  m_uPort;
+	bool            m_bSSL;
+	CString         m_sUserFormat;
 	// !Settings
 
-	TCacheMap<CString>	m_Cache;
+	TCacheMap<CString> m_Cache;
 };
 
 void CIMAPSock::ReadLine(const CString& sLine) {
@@ -134,12 +134,12 @@ void CIMAPSock::ReadLine(const CString& sLine) {
 		}
 
 		Write("AUTH LOGIN " + sUsername + " " + m_spAuth->GetPassword() + "\r\n");
-	} else {
+	} else if (sLine.Left(5) == "AUTH ") {
 		CUser* pUser = CZNC::Get().FindUser(m_spAuth->GetUsername());
 
 		if (pUser && sLine.Equals("AUTH OK", false, 7)) {
 			m_spAuth->AcceptLogin(*pUser);
-			m_pIMAPMod->CacheLogin(CString(m_spAuth->GetUsername() + ":" + m_spAuth->GetPassword()).MD5());		// Use MD5 so passes don't sit in memory in plain text
+			m_pIMAPMod->CacheLogin(CString(m_spAuth->GetUsername() + ":" + m_spAuth->GetPassword()).MD5()); // Use MD5 so passes don't sit in memory in plain text
 			DEBUG("+++ Successful IMAP lookup");
 		} else {
 			m_spAuth->RefuseLogin("Invalid Password");
@@ -151,4 +151,10 @@ void CIMAPSock::ReadLine(const CString& sLine) {
 	}
 }
 
+template<> void TModInfo<CIMAPAuthMod>(CModInfo& Info) {
+	Info.SetWikiPage("imapauth");
+	Info.SetHasArgs(true);
+	Info.SetArgsHelpText("[ server [+]port [ UserFormatString ] ]");
+}
+
 GLOBALMODULEDEFS(CIMAPAuthMod, "Allow users to authenticate via imap")
