@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -13,8 +13,8 @@
  *
  */
 
-#include "Chan.h"
-#include "User.h"
+#include <znc/Chan.h>
+#include <znc/IRCNetwork.h>
 
 class CRejoinJob: public CTimer {
 public:
@@ -26,8 +26,8 @@ public:
 
 protected:
 	virtual void RunJob() {
-		CUser* user = m_pModule->GetUser();
-		CChan* pChan = user->FindChan(GetName().Token(1, true));
+		CIRCNetwork* pNetwork = m_pModule->GetNetwork();
+		CChan* pChan = pNetwork->FindChan(GetName().Token(1, true));
 
 		if (pChan) {
 			pChan->Enable();
@@ -96,7 +96,7 @@ public:
 	}
 
 	virtual void OnKick(const CNick& OpNick, const CString& sKickedNick, CChan& pChan, const CString& sMessage) {
-		if (m_pUser->GetCurNick().Equals(sKickedNick)) {
+		if (m_pNetwork->GetCurNick().Equals(sKickedNick)) {
 			if (!delay) {
 				PutIRC("JOIN " + pChan.GetName() + " " + pChan.GetKey());
 				pChan.Enable();
@@ -110,6 +110,8 @@ public:
 
 template<> void TModInfo<CRejoinMod>(CModInfo& Info) {
 	Info.SetWikiPage("kickrejoin");
+	Info.SetHasArgs(true);
+	Info.SetArgsHelpText("You might enter the number of seconds to wait before rejoining.");
 }
 
-MODULEDEFS(CRejoinMod, "Autorejoin on kick")
+NETWORKMODULEDEFS(CRejoinMod, "Autorejoin on kick")
