@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "Chan.h"
-#include "FileUtils.h"
-#include "IRCSock.h"
-#include "Modules.h"
-#include "Nick.h"
-#include "User.h"
-#include "znc.h"
+#include <znc/Chan.h>
+#include <znc/FileUtils.h>
+#include <znc/IRCSock.h>
+#include <znc/Modules.h>
+#include <znc/Nick.h>
+#include <znc/User.h>
+#include <znc/znc.h>
 
 #include "modperl/module.h"
 #include "modperl/swigperlrun.h"
@@ -22,6 +22,9 @@
 
 #include "modperl/pstring.h"
 
+using std::set;
+using std::vector;
+
 // Allows perl to load .so files when needed by .pm
 // For example, it needs to load ZNC.so
 extern "C" {
@@ -31,10 +34,10 @@ extern "C" {
 	}
 }
 
-class CModPerl: public CGlobalModule {
+class CModPerl: public CModule {
 	PerlInterpreter *m_pPerl;
 public:
-	GLOBALMODCONSTRUCTOR(CModPerl) {
+	MODCONSTRUCTOR(CModPerl) {
 		m_pPerl = NULL;
 	}
 
@@ -60,10 +63,13 @@ public:
 		m_pPerl = perl_alloc();
 		perl_construct(m_pPerl);
 		if (perl_parse(m_pPerl, xs_init, argc, argv, environ)) {
+			sMessage = "Can't initialize perl. ";
+			if (SvTRUE(ERRSV)) {
+				sMessage += PString(ERRSV);
+			}
 			perl_free(m_pPerl);
 			PERL_SYS_TERM();
 			m_pPerl = NULL;
-			sMessage = "Can't initialize perl.";
 			DEBUG(__PRETTY_FUNCTION__ << " can't init perl");
 			return false;
 		}
@@ -75,15 +81,14 @@ public:
 	}
 
 	virtual EModRet OnModuleLoading(const CString& sModName, const CString& sArgs,
-			bool& bSuccess, CString& sRetMsg) {
-		if (!GetUser()) {
-			return CONTINUE;
-		}
+			CModInfo::EModuleType eType, bool& bSuccess, CString& sRetMsg) {
 		EModRet result = HALT;
 		PSTART;
 		PUSH_STR(sModName);
 		PUSH_STR(sArgs);
+		mXPUSHi(eType);
 		PUSH_PTR(CUser*, GetUser());
+		PUSH_PTR(CIRCNetwork*, GetNetwork());
 		PCALL("ZNC::Core::LoadModule");
 
 		if (SvTRUE(ERRSV)) {
@@ -113,20 +118,31 @@ public:
 	virtual EModRet OnModuleUnloading(CModule* pModule, bool& bSuccess, CString& sRetMsg) {
 		CPerlModule* pMod = AsPerlModule(pModule);
 		if (pMod) {
+			EModRet result = HALT;
 			CString sModName = pMod->GetModName();
 			PSTART;
-			PUSH_PTR(CPerlModule*, pMod);
+			XPUSHs(pMod->GetPerlObj());
 			PCALL("ZNC::Core::UnloadModule");
 			if (SvTRUE(ERRSV)) {
 				bSuccess = false;
 				sRetMsg = PString(ERRSV);
+			} else if (ret < 1 || 2 < ret) {
+				sRetMsg = "Error: Perl ZNC::Core::UnloadModule returned " + CString(ret) + " values.";
+				bSuccess = false;
+				result = HALT;
 			} else {
-				bSuccess = true;
-				sRetMsg = "Module [" + sModName + "] unloaded";
+				int bUnloaded = SvUV(ST(0));
+				if (bUnloaded) {
+					bSuccess = true;
+					sRetMsg = "Module [" + sModName + "] unloaded";
+					result = HALT;
+				} else {
+					result = CONTINUE; // module wasn't loaded by modperl. Perhaps a module-provider written in perl did that.
+				}
 			}
 			PEND;
 			DEBUG(__PRETTY_FUNCTION__ << " " << sRetMsg);
-			return HALT;
+			return result;
 		}
 		return CONTINUE;
 	}
@@ -135,6 +151,7 @@ public:
 			bool& bSuccess, CString& sRetMsg) {
 		PSTART;
 		PUSH_STR(sModule);
+		PUSH_PTR(CModInfo*, &ModInfo);
 		PCALL("ZNC::Core::GetModInfo");
 		EModRet result = CONTINUE;
 		if (SvTRUE(ERRSV)) {
@@ -147,12 +164,7 @@ public:
 					break;
 				case Perl_Loaded:
 					result = HALT;
-					if (4 == ret) {
-						ModInfo.SetGlobal(false);
-						ModInfo.SetDescription(PString(ST(2)));
-						ModInfo.SetName(sModule);
-						ModInfo.SetPath(PString(ST(1)));
-						ModInfo.SetWikiPage(PString(ST(3)));
+					if (1 == ret) {
 						bSuccess = true;
 					} else {
 						bSuccess = false;
@@ -174,14 +186,10 @@ public:
 			sRetMsg = "Something weird happened";
 		}
 		PEND;
-		DEBUG(__PRETTY_FUNCTION__ << " " << sRetMsg);
 		return result;
 	}
 
-	virtual void OnGetAvailableMods(set<CModInfo>& ssMods, bool bGlobal) {
-		if (bGlobal) {
-			return;
-		}
+	virtual void OnGetAvailableMods(set<CModInfo>& ssMods, CModInfo::EModuleType eType) {
 
 		unsigned int a = 0;
 		CDir Dir;
@@ -201,13 +209,9 @@ public:
 				PSTART;
 				PUSH_STR(sPath);
 				PUSH_STR(sName);
+				PUSH_PTR(CModInfo*, &ModInfo);
 				PCALL("ZNC::Core::ModInfoByPath");
-				if (!SvTRUE(ERRSV) && ret == 2) {
-					ModInfo.SetGlobal(false);
-					ModInfo.SetDescription(PString(ST(0)));
-					ModInfo.SetName(sName);
-					ModInfo.SetPath(sPath);
-					ModInfo.SetWikiPage(PString(ST(1)));
+				if (!SvTRUE(ERRSV)) {
 					ssMods.insert(ModInfo);
 				}
 				PEND;
@@ -242,8 +246,7 @@ void CPerlTimer::RunJob() {
 	CPerlModule* pMod = AsPerlModule(GetModule());
 	if (pMod) {
 		PSTART;
-		PUSH_STR(pMod->GetPerlID());
-		PUSH_STR(GetPerlID());
+		XPUSHs(GetPerlObj());
 		PCALL("ZNC::Core::CallTimer");
 		PEND;
 	}
@@ -253,14 +256,13 @@ CPerlTimer::~CPerlTimer() {
 	CPerlModule* pMod = AsPerlModule(GetModule());
 	if (pMod) {
 		PSTART;
-		PUSH_STR(pMod->GetPerlID());
-		PUSH_STR(GetPerlID());
+		XPUSHs(sv_2mortal(m_perlObj));
 		PCALL("ZNC::Core::RemoveTimer");
 		PEND;
 	}
 }
 
-#define SOCKSTART PSTART; PUSH_STR(pMod->GetPerlID()); PUSH_STR(GetPerlID())
+#define SOCKSTART PSTART; XPUSHs(GetPerlObj())
 #define SOCKCBCHECK(OnSuccess) PCALL("ZNC::Core::CallSocket"); if (SvTRUE(ERRSV)) { Close(); DEBUG("Perl socket hook died with: " + PString(ERRSV)); } else { OnSuccess; } PEND
 #define CBSOCK(Func) void CPerlSocket::Func() {\
 	CPerlModule* pMod = AsPerlModule(GetModule());\
@@ -312,7 +314,8 @@ Csock* CPerlSocket::GetSockObj(const CString& sHost, unsigned short uPort) {
 CPerlSocket::~CPerlSocket() {
 	CPerlModule* pMod = AsPerlModule(GetModule());
 	if (pMod) {
-		SOCKSTART;
+		PSTART;
+		XPUSHs(sv_2mortal(m_perlObj));
 		PCALL("ZNC::Core::RemoveSocket");
 		PEND;
 	}
