@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -8,21 +8,27 @@
 
 #pragma once
 
-#include "Modules.h"
+#include <EXTERN.h>
+#include <perl.h>
+#include <XSUB.h>
+
+#include <znc/Modules.h>
 
 #if HAVE_VISIBILITY
 #pragma GCC visibility push(default)
 #endif
 class CPerlModule : public CModule {
-	CString m_sPerlID;
+	SV* m_perlObj;
 	VWebSubPages* _GetSubPages();
 public:
-	CPerlModule(CUser* pUser, const CString& sModName, const CString& sDataPath,
-			const CString& sPerlID)
-			: CModule(NULL, pUser, sModName, sDataPath) {
-		m_sPerlID = sPerlID;
+	CPerlModule(CUser* pUser, CIRCNetwork* pNetwork, const CString& sModName, const CString& sDataPath,
+			SV* perlObj)
+			: CModule(NULL, pUser, pNetwork, sModName, sDataPath) {
+		m_perlObj = newSVsv(perlObj);
+	}
+	SV* GetPerlObj() {
+		return sv_2mortal(newSVsv(m_perlObj));
 	}
-	CString GetPerlID() { return m_sPerlID; }
 
 	virtual bool OnBoot();
 	virtual bool WebRequiresLogin();
@@ -51,8 +57,8 @@ public:
 	virtual void OnModCommand(const CString& sCommand);
 	virtual void OnModNotice(const CString& sMessage);
 	virtual void OnModCTCP(const CString& sMessage);
-	virtual void OnQuit(const CNick& Nick, const CString& sMessage, const vector<CChan*>& vChans);
-	virtual void OnNick(const CNick& Nick, const CString& sNewNick, const vector<CChan*>& vChans);
+	virtual void OnQuit(const CNick& Nick, const CString& sMessage, const std::vector<CChan*>& vChans);
+	virtual void OnNick(const CNick& Nick, const CString& sNewNick, const std::vector<CChan*>& vChans);
 	virtual void OnKick(const CNick& OpNick, const CString& sKickedNick, CChan& Channel, const CString& sMessage);
 	virtual void OnJoin(const CNick& Nick, CChan& Channel);
 	virtual void OnPart(const CNick& Nick, CChan& Channel, const CString& sMessage);
@@ -99,27 +105,31 @@ enum ELoadPerlMod {
 };
 
 class CPerlTimer : public CTimer {
-	CString m_sPerlID;
+	SV* m_perlObj;
 public:
-	CPerlTimer(CPerlModule* pModule, unsigned int uInterval, unsigned int uCycles, const CString& sLabel, const CString& sDescription, const CString& sPerlID)
-					: CTimer (pModule, uInterval, uCycles, sLabel, sDescription), m_sPerlID(sPerlID) {
+	CPerlTimer(CPerlModule* pModule, unsigned int uInterval, unsigned int uCycles, const CString& sLabel, const CString& sDescription, SV* perlObj)
+					: CTimer (pModule, uInterval, uCycles, sLabel, sDescription), m_perlObj(newSVsv(perlObj)) {
 		pModule->AddTimer(this);
 	}
 	virtual void RunJob();
-	CString GetPerlID() { return m_sPerlID; }
+	SV* GetPerlObj() {
+		return sv_2mortal(newSVsv(m_perlObj));
+	}
 	~CPerlTimer();
 };
 
 inline CPerlTimer* CreatePerlTimer(CPerlModule* pModule, unsigned int uInterval, unsigned int uCycles,
-		const CString& sLabel, const CString& sDescription, const CString& sPerlID) {
-	return new CPerlTimer(pModule, uInterval, uCycles, sLabel, sDescription, sPerlID);
+		const CString& sLabel, const CString& sDescription, SV* perlObj) {
+	return new CPerlTimer(pModule, uInterval, uCycles, sLabel, sDescription, perlObj);
 }
 
 class CPerlSocket : public CSocket {
-	CString m_sPerlID;
+	SV* m_perlObj;
 public:
-	CPerlSocket(CPerlModule* pModule, const CString& sPerlID) : CSocket(pModule), m_sPerlID(sPerlID) {}
-	CString GetPerlID() { return m_sPerlID; }
+	CPerlSocket(CPerlModule* pModule, SV* perlObj) : CSocket(pModule), m_perlObj(newSVsv(perlObj)) {}
+	SV* GetPerlObj() {
+		return sv_2mortal(newSVsv(m_perlObj));
+	}
 	~CPerlSocket();
 	virtual void Connected();
 	virtual void Disconnected();
@@ -130,8 +140,8 @@ public:
 	virtual Csock* GetSockObj(const CString& sHost, unsigned short uPort);
 };
 
-inline CPerlSocket* CreatePerlSocket(CPerlModule* pModule, const CString& sPerlID) {
-	return new CPerlSocket(pModule, sPerlID);
+inline CPerlSocket* CreatePerlSocket(CPerlModule* pModule, SV* perlObj) {
+	return new CPerlSocket(pModule, perlObj);
 }
 
 inline bool HaveIPv6() {
@@ -148,13 +158,6 @@ inline bool HaveSSL() {
 	return false;
 }
 
-inline bool HaveCAres() {
-#ifdef HAVE_C_ARES
-	return true;
-#endif
-	return false;
-}
-
 inline int _GetSOMAXCONN() {
 	return SOMAXCONN;
 }
@@ -172,7 +175,7 @@ inline double GetVersion() {
 }
 
 inline CString GetVersionExtra() {
-	return VERSION_EXTRA;
+	return ZNC_VERSION_EXTRA;
 }
 #if HAVE_VISIBILITY
 #pragma GCC visibility pop
