@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -8,22 +8,26 @@
 
 #include <Python.h>
 
-#include "Chan.h"
-#include "FileUtils.h"
-#include "IRCSock.h"
-#include "Modules.h"
-#include "Nick.h"
-#include "User.h"
-#include "znc.h"
+#include <znc/Chan.h>
+#include <znc/FileUtils.h>
+#include <znc/IRCSock.h>
+#include <znc/Modules.h>
+#include <znc/Nick.h>
+#include <znc/User.h>
+#include <znc/znc.h>
 
 #include "modpython/swigpyrun.h"
 #include "modpython/module.h"
-#include "modpython/retstring.h"
+#include "modpython/ret.h"
 
-class CModPython: public CGlobalModule {
+using std::vector;
+using std::set;
+
+class CModPython: public CModule {
 
 	PyObject* m_PyZNCModule;
 	PyObject* m_PyFormatException;
+	vector<PyObject*> m_vpObject;
 
 public:
 
@@ -69,7 +73,7 @@ public:
 			return result;
 	}
 
-	GLOBALMODCONSTRUCTOR(CModPython) {
+	MODCONSTRUCTOR(CModPython) {
 		Py_Initialize();
 		m_PyFormatException = NULL;
 		m_PyZNCModule = NULL;
@@ -77,8 +81,13 @@ public:
 
 	bool OnLoad(const CString& sArgsi, CString& sMessage) {
 		CString sModPath, sTmp;
-		if (!CModules::FindModPath("modpython/_znc_core.so", sModPath, sTmp)) {
-			sMessage = "modpython/_znc_core.so not found.";
+#ifdef __CYGWIN__
+		CString sDllPath = "modpython/_znc_core.dll";
+#else
+		CString sDllPath = "modpython/_znc_core.so";
+#endif
+		if (!CModules::FindModPath(sDllPath, sModPath, sTmp)) {
+			sMessage = sDllPath + " not found.";
 			return false;
 		}
 		sTmp = CDir::ChangeDir(sModPath, "..");
@@ -127,10 +136,7 @@ public:
 	}
 
 	virtual EModRet OnModuleLoading(const CString& sModName, const CString& sArgs,
-			bool& bSuccess, CString& sRetMsg) {
-		if (!GetUser()) {
-			return CONTINUE;
-		}
+			CModInfo::EModuleType eType, bool& bSuccess, CString& sRetMsg) {
 		PyObject* pyFunc = PyObject_GetAttrString(m_PyZNCModule, "load_module");
 		if (!pyFunc) {
 			sRetMsg = GetPyExceptionStr();
@@ -138,12 +144,14 @@ public:
 			bSuccess = false;
 			return HALT;
 		}
-		PyObject* pyRes = PyObject_CallFunction(pyFunc, const_cast<char*>("ssNNN"),
+		PyObject* pyRes = PyObject_CallFunction(pyFunc, const_cast<char*>("ssiNNNN"),
 				sModName.c_str(),
 				sArgs.c_str(),
-				SWIG_NewInstanceObj(GetUser(), SWIG_TypeQuery("CUser*"), 0),
+				(int)eType,
+				(eType == CModInfo::GlobalModule ? Py_None : SWIG_NewInstanceObj(GetUser(), SWIG_TypeQuery("CUser*"), 0)),
+				(eType == CModInfo::NetworkModule ? SWIG_NewInstanceObj(GetNetwork(), SWIG_TypeQuery("CIRCNetwork*"), 0) : Py_None),
 				CPyRetString::wrap(sRetMsg),
-				SWIG_NewInstanceObj(reinterpret_cast<CGlobalModule*>(this), SWIG_TypeQuery("CGlobalModule*"), 0));
+				SWIG_NewInstanceObj(reinterpret_cast<CModule*>(this), SWIG_TypeQuery("CModPython*"), 0));
 		if (!pyRes) {
 			sRetMsg = GetPyExceptionStr();
 			DEBUG("modpython: " << sRetMsg);
@@ -174,7 +182,7 @@ public:
 				return HALT;
 		}
 		bSuccess = false;
-		sRetMsg += " unknown value returned by modperl.load_module";
+		sRetMsg += " unknown value returned by modpython.load_module";
 		return HALT;
 	}
 
@@ -197,6 +205,11 @@ public:
 				Py_CLEAR(pyFunc);
 				return HALT;
 			}
+			if (!PyObject_IsTrue(pyRes)) {
+				// python module, but not handled by modpython itself.
+				// some module-provider written on python loaded it?
+				return CONTINUE;
+			}
 			Py_CLEAR(pyFunc);
 			Py_CLEAR(pyRes);
 			bSuccess = true;
@@ -252,7 +265,7 @@ public:
 		return HALT;
 	}
 
-	void TryAddModInfo(const CString& sPath, const CString& sName, set<CModInfo>& ssMods, set<CString>& ssAlready) {
+	void TryAddModInfo(const CString& sPath, const CString& sName, set<CModInfo>& ssMods, set<CString>& ssAlready, CModInfo::EModuleType eType) {
 		if (ssAlready.count(sName)) {
 			return;
 		}
@@ -282,51 +295,37 @@ public:
 			return;
 		}
 		Py_CLEAR(pyRes);
-		if (x) {
+		if (x && ModInfo.SupportsType(eType)) {
 			ssMods.insert(ModInfo);
 			ssAlready.insert(sName);
 		}
 	}
 
-	virtual void OnGetAvailableMods(set<CModInfo>& ssMods, bool bGlobal) {
-		if (bGlobal) {
-			return;
-		}
-
+	virtual void OnGetAvailableMods(set<CModInfo>& ssMods, CModInfo::EModuleType eType) {
 		CDir Dir;
 		CModules::ModDirList dirs = CModules::GetModDirs();
 
 		while (!dirs.empty()) {
 			set<CString> already;
 
-			Dir.FillByWildcard(dirs.front().first, "*.py");
+			Dir.Fill(dirs.front().first);
 			for (unsigned int a = 0; a < Dir.size(); a++) {
 				CFile& File = *Dir[a];
 				CString sName = File.GetShortName();
 				CString sPath = File.GetLongName();
 				sPath.TrimSuffix(sName);
-				sName.RightChomp(3);
-				TryAddModInfo(sPath, sName, ssMods, already);
-			}
 
-			Dir.FillByWildcard(dirs.front().first, "*.pyc");
-			for (unsigned int a = 0; a < Dir.size(); a++) {
-				CFile& File = *Dir[a];
-				CString sName = File.GetShortName();
-				CString sPath = File.GetLongName();
-				sPath.TrimSuffix(sName);
-				sName.RightChomp(4);
-				TryAddModInfo(sPath, sName, ssMods, already);
-			}
+				if (!File.IsDir()) {
+					if (sName.WildCmp("*.pyc")) {
+						sName.RightChomp(4);
+					} else if (sName.WildCmp("*.py") || sName.WildCmp("*.so")) {
+						sName.RightChomp(3);
+					} else {
+						continue;
+					}
+				}
 
-			Dir.FillByWildcard(dirs.front().first, "*.so");
-			for (unsigned int a = 0; a < Dir.size(); a++) {
-				CFile& File = *Dir[a];
-				CString sName = File.GetShortName();
-				CString sPath = File.GetLongName();
-				sPath.TrimSuffix(sName);
-				sName.RightChomp(3);
-				TryAddModInfo(sPath, sName, ssMods, already);
+				TryAddModInfo(sPath, sName, ssMods, already, eType);
 			}
 
 			dirs.pop();
@@ -334,28 +333,24 @@ public:
 	}
 
 	virtual ~CModPython() {
-		const map<CString, CUser*>& users = CZNC::Get().GetUserMap();
-		for (map<CString, CUser*>::const_iterator i = users.begin(); i != users.end(); ++i) {
-			CModules& M = i->second->GetModules();
-			bool cont;
-			do {
-				cont = false;
-				for (CModules::iterator it = M.begin(); it != M.end(); ++it) {
-					CModule* m = *it;
-					CPyModule* mod = AsPyModule(m);
-					if (mod) {
-						cont = true;
-						bool bSuccess = false;
-						CString sRetMsg;
-						OnModuleUnloading(mod, bSuccess, sRetMsg);
-						if (!bSuccess) {
-							DEBUG("Error unloading python module in ~CModPython: " << sRetMsg);
-						}
-						break;
-					}
-				}
-			} while (cont);
+		if (!m_PyZNCModule) {
+			DEBUG("~CModPython(): seems like CModPython::OnLoad() didn't initialize python");
+			return;
 		}
+		PyObject* pyFunc = PyObject_GetAttrString(m_PyZNCModule, "unload_all");
+		if (!pyFunc) {
+			CString sRetMsg = GetPyExceptionStr();
+			DEBUG("~CModPython(): couldn't find unload_all: " << sRetMsg);
+			return;
+		}
+		PyObject* pyRes = PyObject_CallFunctionObjArgs(pyFunc, NULL);
+		if (!pyRes) {
+			CString sRetMsg = GetPyExceptionStr();
+			DEBUG("modpython tried to unload all modules in its destructor, but: " << sRetMsg);
+		}
+		Py_CLEAR(pyRes);
+		Py_CLEAR(pyFunc);
+
 		Py_CLEAR(m_PyFormatException);
 		Py_CLEAR(m_PyZNCModule);
 		Py_Finalize();
@@ -461,23 +456,6 @@ CPySocket::~CPySocket() {
 	Py_CLEAR(m_pyObj);
 }
 
-PyObject* CPySocket::WriteBytes(PyObject* data) {
-	if (!PyBytes_Check(data)) {
-		PyErr_SetString(PyExc_TypeError, "socket.WriteBytes needs bytes as argument");
-		return NULL;
-	}
-	char* buffer;
-	Py_ssize_t length;
-	if (-1 == PyBytes_AsStringAndSize(data, &buffer, &length)) {
-		return NULL;
-	}
-	if (Write(buffer, length)) {
-		Py_RETURN_TRUE;
-	} else {
-		Py_RETURN_FALSE;
-	}
-}
-
 template<> void TModInfo<CModPython>(CModInfo& Info) {
 	Info.SetWikiPage("modpython");
 }
