@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -23,12 +23,12 @@ class CPyModule : public CModule {
 	CModPython* m_pModPython;
 	VWebSubPages* _GetSubPages();
 public:
-	CPyModule(CUser* pUser, const CString& sModName, const CString& sDataPath,
-			PyObject* pyObj, CGlobalModule* pModPython)
-			: CModule(NULL, pUser, sModName, sDataPath) {
+	CPyModule(CUser* pUser, CIRCNetwork* pNetwork, const CString& sModName, const CString& sDataPath,
+			PyObject* pyObj, CModPython* pModPython)
+			: CModule(NULL, pUser, pNetwork, sModName, sDataPath) {
 		m_pyObj = pyObj;
 		Py_INCREF(pyObj);
-		m_pModPython = reinterpret_cast<CModPython*>(pModPython);
+		m_pModPython = pModPython;
 	}
 	PyObject* GetPyObj() { // borrows
 		return m_pyObj;
@@ -73,8 +73,8 @@ public:
 	virtual void OnModCommand(const CString& sCommand);
 	virtual void OnModNotice(const CString& sMessage);
 	virtual void OnModCTCP(const CString& sMessage);
-	virtual void OnQuit(const CNick& Nick, const CString& sMessage, const vector<CChan*>& vChans);
-	virtual void OnNick(const CNick& Nick, const CString& sNewNick, const vector<CChan*>& vChans);
+	virtual void OnQuit(const CNick& Nick, const CString& sMessage, const std::vector<CChan*>& vChans);
+	virtual void OnNick(const CNick& Nick, const CString& sNewNick, const std::vector<CChan*>& vChans);
 	virtual void OnKick(const CNick& OpNick, const CString& sKickedNick, CChan& Channel, const CString& sMessage);
 	virtual void OnJoin(const CNick& Nick, CChan& Channel);
 	virtual void OnPart(const CNick& Nick, CChan& Channel, const CString& sMessage);
@@ -108,14 +108,31 @@ public:
 	virtual void OnServerCapResult(const CString& sCap, bool bSuccess);
 	virtual EModRet OnTimerAutoJoin(CChan& Channel);
 	bool OnEmbeddedWebRequest(CWebSock&, const CString&, CTemplate&);
+
+	// Global Modules
+	virtual EModRet OnAddUser(CUser& User, CString& sErrorRet);
+	virtual EModRet OnDeleteUser(CUser& User);
+	virtual void OnClientConnect(CZNCSock* pSock, const CString& sHost, unsigned short uPort);
+	virtual void OnFailedLogin(const CString& sUsername, const CString& sRemoteIP);
+	virtual EModRet OnUnknownUserRaw(CClient* pClient, CString& sLine);
+	virtual bool IsClientCapSupported(CClient* pClient, const CString& sCap, bool bState);
+	virtual void OnClientCapRequest(CClient* pClient, const CString& sCap, bool bState);
+	virtual EModRet OnModuleLoading(const CString& sModName, const CString& sArgs,
+			CModInfo::EModuleType eType, bool& bSuccess, CString& sRetMsg);
+	virtual EModRet OnModuleUnloading(CModule* pModule, bool& bSuccess, CString& sRetMsg);
+	virtual EModRet OnGetModInfo(CModInfo& ModInfo, const CString& sModule,
+			bool& bSuccess, CString& sRetMsg);
+	virtual void OnGetAvailableMods(std::set<CModInfo>& ssMods, CModInfo::EModuleType eType);
+	virtual void OnClientCapLs(CClient* pClient, SCString& ssCaps);
+	virtual EModRet OnLoginAttempt(CSmartPtr<CAuthBase> Auth);
 };
 
 static inline CPyModule* AsPyModule(CModule* p) {
 	return dynamic_cast<CPyModule*>(p);
 }
 
-inline CPyModule* CreatePyModule(CUser* pUser, const CString& sModName, const CString& sDataPath, PyObject* pyObj, CGlobalModule* pModPython) {
-	return new CPyModule(pUser, sModName, sDataPath, pyObj, pModPython);
+inline CPyModule* CreatePyModule(CUser* pUser, CIRCNetwork* pNetwork, const CString& sModName, const CString& sDataPath, PyObject* pyObj, CModPython* pModPython) {
+	return new CPyModule(pUser, pNetwork, sModName, sDataPath, pyObj, pModPython);
 }
 
 class CPyTimer : public CTimer {
@@ -163,7 +180,6 @@ public:
 	virtual void ReadData(const char *data, size_t len);
 	virtual void ReadLine(const CString& sLine);
 	virtual Csock* GetSockObj(const CString& sHost, unsigned short uPort);
-	PyObject* WriteBytes(PyObject* data);
 };
 
 inline CPySocket* CreatePySocket(CPyModule* pModule, PyObject* pyObj) {
@@ -184,13 +200,6 @@ inline bool HaveSSL_() {
 	return false;
 }
 
-inline bool HaveCAres_() {
-#ifdef HAVE_C_ARES
-	return true;
-#endif
-	return false;
-}
-
 inline int GetSOMAXCONN() {
 	return SOMAXCONN;
 }
@@ -208,7 +217,7 @@ inline double GetVersion() {
 }
 
 inline CString GetVersionExtra() {
-	return VERSION_EXTRA;
+	return ZNC_VERSION_EXTRA;
 }
 
 class MCString_iter {
@@ -227,6 +236,29 @@ public:
 	}
 };
 
+class CModulesIter {
+public:
+	CModulesIter(CModules *pModules) {
+		m_pModules = pModules;
+		m_it = pModules->begin();
+	}
+
+	void plusplus() {
+		++m_it;
+	}
+
+	const CModule* get() const {
+		return *m_it;
+	}
+
+	bool is_end() const {
+		return m_pModules->end() == m_it;
+	}
+
+	CModules *m_pModules;
+	CModules::const_iterator m_it;
+};
+
 #if HAVE_VISIBILITY
 #pragma GCC visibility pop
 #endif
