@@ -1,20 +1,24 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "Chan.h"
-#include "IRCSock.h"
-#include "Modules.h"
-#include "Server.h"
-#include "User.h"
-#include "znc.h"
+#include <znc/Chan.h>
+#include <znc/IRCSock.h>
+#include <znc/Modules.h>
+#include <znc/Server.h>
+#include <znc/User.h>
+#include <znc/IRCNetwork.h>
+#include <znc/znc.h>
 
 #include <tcl.h>
 
+using std::vector;
+using std::map;
+
 #define STDVAR (ClientData cd, Tcl_Interp *irp, int argc, const char *argv[])
 
 #define BADARGS(nl, nh, example) do {                               \
@@ -78,18 +82,17 @@ public:
 		interp = Tcl_CreateInterp();
 		Tcl_Init(interp);
 		Tcl_CreateCommand(interp, "Binds::ProcessPubm", tcl_Bind, this, NULL);
+		Tcl_CreateCommand(interp, "Binds::ProcessMsgm", tcl_Bind, this, NULL);
 		Tcl_CreateCommand(interp, "Binds::ProcessTime", tcl_Bind, this, NULL);
 		Tcl_CreateCommand(interp, "Binds::ProcessEvnt", tcl_Bind, this, NULL);
 		Tcl_CreateCommand(interp, "Binds::ProcessNick", tcl_Bind, this, NULL);
 		Tcl_CreateCommand(interp, "Binds::ProcessKick", tcl_Bind, this, NULL);
 		Tcl_CreateCommand(interp, "PutIRC", tcl_PutIRC, this, NULL);
-		Tcl_CreateCommand(interp, "PutIRCAs", tcl_PutIRCAs, this, NULL);
 		Tcl_CreateCommand(interp, "PutModule", tcl_PutModule, this, NULL);
 		Tcl_CreateCommand(interp, "PutStatus", tcl_PutStatus, this, NULL);
 		Tcl_CreateCommand(interp, "PutStatusNotice", tcl_PutStatusNotice, this, NULL);
 		Tcl_CreateCommand(interp, "PutUser", tcl_PutUser, this, NULL);
 
-		Tcl_CreateCommand(interp, "GetLocalIP", tcl_GetLocalIP, this, NULL);
 		Tcl_CreateCommand(interp, "GetCurNick", tcl_GetCurNick, this, NULL);
 		Tcl_CreateCommand(interp, "GetUsername", tcl_GetUsername, this, NULL);
 		Tcl_CreateCommand(interp, "GetRealName", tcl_GetRealName, this, NULL);
@@ -101,6 +104,7 @@ public:
 		Tcl_CreateCommand(interp, "GetServer", tcl_GetServer, this, NULL);
 		Tcl_CreateCommand(interp, "GetServerOnline", tcl_GetServerOnline, this, NULL);
 		Tcl_CreateCommand(interp, "GetModules", tcl_GetModules, this, NULL);
+		Tcl_CreateCommand(interp, "GetClientCount", tcl_GetClientCount, this, NULL);
 
 		Tcl_CreateCommand(interp, "exit", tcl_exit, this, NULL);
 
@@ -187,6 +191,19 @@ public:
 		return CONTINUE;
 	}
 
+	virtual EModRet OnPrivMsg(CNick& Nick, CString& sMessage) {
+		CString sMes = TclEscape(sMessage);
+		CString sNick = TclEscape(CString(Nick.GetNick()));
+		CString sHost = TclEscape(CString(Nick.GetIdent() + "@" + Nick.GetHost()));
+
+		CString sCommand = "Binds::ProcessMsgm {" + sNick + "} {" + sHost + "} - {" + sMes + "}";
+		i = Tcl_Eval(interp, sCommand.c_str());
+		if (i != TCL_OK) {
+			PutModule(Tcl_GetStringResult(interp));
+		}
+		return CONTINUE;
+	}
+
 	virtual void OnNick(const CNick& OldNick, const CString& sNewNick, const vector<CChan*>& vChans) {
 		CString sOldNick = TclEscape(CString(OldNick.GetNick()));
 		CString sNewNickTmp = TclEscape(sNewNick);
@@ -237,15 +254,9 @@ private:
 	// Placeholder for binds incase binds.tcl isn't used
 	static int tcl_Bind STDVAR {return TCL_OK;}
 
-	static int tcl_GetLocalIP STDVAR {
-		CModTcl *mod = static_cast<CModTcl *>(cd);
-		Tcl_SetResult(irp, (char *)mod->m_pUser->GetLocalIP().c_str(), TCL_VOLATILE);
-		return TCL_OK;
-	}
-
 	static int tcl_GetCurNick STDVAR {
 		CModTcl *mod = static_cast<CModTcl *>(cd);
-		Tcl_SetResult(irp, (char *)mod->m_pUser->GetCurNick().c_str(), TCL_VOLATILE);
+		Tcl_SetResult(irp, (char *)mod->m_pNetwork->GetCurNick().c_str(), TCL_VOLATILE);
 		return TCL_OK;
 	}
 
@@ -274,7 +285,7 @@ private:
 
 		BADARGS(1, 1, "");
 
-		const vector<CChan*>& Channels = mod->m_pUser->GetChans();
+		const vector<CChan*>& Channels = mod->m_pNetwork->GetChans();
 		for (unsigned int c = 0; c < Channels.size(); c++) {
 			CChan* pChan = Channels[c];
 			l[0] = pChan->GetName().c_str();
@@ -294,7 +305,7 @@ private:
 		BADARGS(2, 999, " channel");
 
 		CString sChannel = argvit(argv, argc, 1, " ");
-		CChan *pChannel = mod->m_pUser->FindChan(sChannel);
+		CChan *pChannel = mod->m_pNetwork->FindChan(sChannel);
 
 		if (!pChannel) {
 			CString sMsg = "invalid channel: " + sChannel;
@@ -323,7 +334,7 @@ private:
 		BADARGS(2, 999, " channel");
 
 		CString sChannel = argvit(argv, argc, 1, " ");
-		CChan *pChannel = mod->m_pUser->FindChan(sChannel);
+		CChan *pChannel = mod->m_pNetwork->FindChan(sChannel);
 		CString sMsg;
 
 		if (!pChannel) {
@@ -339,7 +350,7 @@ private:
 
 	static int tcl_GetServer STDVAR {
 		CModTcl *mod = static_cast<CModTcl *>(cd);
-		CServer* pServer = mod->m_pUser->GetCurrentServer();
+		CServer* pServer = mod->m_pNetwork->GetCurrentServer();
 		CString sMsg;
 		if (pServer)
 			sMsg = pServer->GetName() + ":" + CString(pServer->GetPort());
@@ -349,7 +360,7 @@ private:
 
 	static int tcl_GetServerOnline STDVAR {
 		CModTcl *mod = static_cast<CModTcl *>(cd);
-		CIRCSock* pIRCSock = mod->m_pUser->GetIRCSock();
+		CIRCSock* pIRCSock = mod->m_pNetwork->GetIRCSock();
 		CString sMsg = "0";
 		if (pIRCSock)
 			sMsg = CString(pIRCSock->GetStartTime());
@@ -387,30 +398,19 @@ private:
 		return TCL_OK;
 	}
 
+	static int tcl_GetClientCount STDVAR {
+		CModTcl *mod = static_cast<CModTcl *>(cd);
+		Tcl_SetResult(irp, (char *)CString(mod->m_pNetwork->GetClients().size()).c_str(), TCL_VOLATILE);
+		return TCL_OK;
+	}
+
 	static int tcl_PutIRC STDVAR {
 		CString sMsg;
 		CModTcl *mod = static_cast<CModTcl *>(cd);
 
 		BADARGS(2, 999, " string");
 		sMsg = argvit(argv, argc, 1, " ");
-		mod->m_pUser->PutIRC(sMsg);
-		return TCL_OK;
-	}
-
-	static int tcl_PutIRCAs STDVAR {
-		CString sMsg;
-
-		BADARGS(3, 999, " user string");
-
-		CUser *pUser = CZNC::Get().FindUser(argv[1]);
-		if (!pUser) {
-			sMsg = "invalid user " + CString(argv[1]);
-			Tcl_SetResult(irp, (char*)sMsg.c_str(), TCL_VOLATILE);
-			return TCL_ERROR;
-		}
-
-		sMsg = argvit(argv, argc, 2, " ");
-		pUser->PutIRC(sMsg);
+		mod->m_pNetwork->PutIRC(sMsg);
 		return TCL_OK;
 	}
 
@@ -496,6 +496,8 @@ void CModTclStartTimer::RunJob() {
 
 template<> void TModInfo<CModTcl>(CModInfo& Info) {
 	Info.SetWikiPage("modtcl");
+	Info.SetHasArgs(true);
+	Info.SetArgsHelpText("Absolute path to modtcl.tcl file");
 }
 
-MODULEDEFS(CModTcl, "Loads Tcl scripts as ZNC modules")
+NETWORKMODULEDEFS(CModTcl, "Loads Tcl scripts as ZNC modules")
