@@ -1,18 +1,18 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "Chan.h"
-#include "HTTPSock.h"
-#include "Server.h"
-#include "Template.h"
-#include "User.h"
-#include "znc.h"
-#include "WebModules.h"
+#include <znc/Chan.h>
+#include <znc/HTTPSock.h>
+#include <znc/Server.h>
+#include <znc/Template.h>
+#include <znc/User.h>
+#include <znc/znc.h>
+#include <znc/WebModules.h>
 #include <sstream>
 
 using std::stringstream;
@@ -200,11 +200,11 @@ public:
 			return true;
 		} else if (sPageName == "delnote") {
 			DelNote(WebSock.GetParam("key", false));
-			WebSock.Redirect("/mods/notes/");
+			WebSock.Redirect(GetWebPath());
 			return true;
 		} else if (sPageName == "addnote") {
 			AddNote(WebSock.GetParam("key"), WebSock.GetParam("note"));
-			WebSock.Redirect("/mods/notes/");
+			WebSock.Redirect(GetWebPath());
 			return true;
 		}
 
@@ -214,6 +214,8 @@ public:
 
 template<> void TModInfo<CNotesMod>(CModInfo& Info) {
 	Info.SetWikiPage("notes");
+	Info.SetHasArgs(true);
+	Info.SetArgsHelpText("This user module takes up to one arguments. It can be -disableNotesOnLogin not to show notes upon client login");
 }
 
-MODULEDEFS(CNotesMod, "Keep and replay notes")
+USERMODULEDEFS(CNotesMod, "Keep and replay notes")
