@@ -1,14 +1,14 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "znc.h"
-#include "User.h"
-#include "IRCSock.h"
+#include <znc/znc.h>
+#include <znc/IRCNetwork.h>
+#include <znc/IRCSock.h>
 
 struct reply {
 	const char *szReply;
@@ -18,34 +18,36 @@ struct reply {
 // TODO this list is far from complete, no errors are handled
 static const struct {
 	const char *szRequest;
-	struct reply vReplies[10];
+	struct reply vReplies[16];
 } vRouteReplies[] = {
 	{"WHO", {
-		{"352", false},
+		{"402", true},  /* rfc1459 ERR_NOSUCHSERVER */
+		{"352", false},  /* rfc1459 RPL_WHOREPLY */
+		{"315", true},  /* rfc1459 RPL_ENDOFWHO */
 		{"354", false}, // e.g. Quaknet uses this for WHO #chan %n
 		{"403", true}, // No such chan
-		{"315", true},
 		{NULL, true}
 	}},
 	{"LIST", {
-		{"321", false},
-		{"322", false},
-		{"323", true},
+		{"402", true},  /* rfc1459 ERR_NOSUCHSERVER */
+		{"321", false},  /* rfc1459 RPL_LISTSTART */
+		{"322", false},  /* rfc1459 RPL_LIST */
+		{"323", true},  /* rfc1459 RPL_LISTEND */
 		{NULL, true}
 	}},
 	{"NAMES", {
-		{"353", false},
-		{"366", true},
+		{"353", false},  /* rfc1459 RPL_NAMREPLY */
+		{"366", true},  /* rfc1459 RPL_ENDOFNAMES */
 		// No such nick/channel
 		{"401", true},
 		{NULL, true},
 	}},
 	{"LUSERS", {
-		{"251", false},
-		{"252", false},
-		{"253", false},
-		{"254", false},
-		{"255", false},
+		{"251", false},  /* rfc1459 RPL_LUSERCLIENT */
+		{"252", false},  /* rfc1459 RPL_LUSEROP */
+		{"253", false},  /* rfc1459 RPL_LUSERUNKNOWN */
+		{"254", false},  /* rfc1459 RPL_LUSERCHANNELS */
+		{"255", false},  /* rfc1459 RPL_LUSERME */
 		{"265", false},
 		{"266", true},
 		// We don't handle 250 here since some IRCds don't sent it
@@ -53,43 +55,53 @@ static const struct {
 		{NULL, true}
 	}},
 	{"WHOIS", {
-		{"311", false},
-		{"319", false},
-		{"312", false},
+		{"311", false},  /* rfc1459 RPL_WHOISUSER */
+		{"312", false},  /* rfc1459 RPL_WHOISSERVER */
+		{"313", false},  /* rfc1459 RPL_WHOISOPERATOR */
+		{"317", false},  /* rfc1459 RPL_WHOISIDLE */
+		{"319", false},  /* rfc1459 RPL_WHOISCHANNELS */
 		// "<ip> :actually using host"
 		{"338", false},
-		{"318", true},
-		// No such nick/channel
-		{"401", true},
-		// No such server
-		{"402", true},
+		{"301", false},  /* rfc1459 RPL_AWAY */
+		{"318", true},  /* rfc1459 RPL_ENDOFWHOIS */
+		{"401", true},  /* rfc1459 ERR_NOSUCHNICK */
+		{"402", true},  /* rfc1459 ERR_NOSUCHSERVER */
+		{"431", true},  /* rfc1459 ERR_NONICKNAMEGIVEN */
 		{NULL, true}
 	}},
 	{"PING", {
 		{"PONG", true},
+		{"402", true},  /* rfc1459 ERR_NOSUCHSERVER */
+		{"409", true},  /* rfc1459 ERR_NOORIGIN */
 		{NULL, true}
 	}},
 	{"USERHOST", {
 		{"302", true},
+		{"461", true},  /* rfc1459 ERR_NEEDMOREPARAMS */
 		{NULL, true}
 	}},
 	{"TIME", {
-		{"391", true},
+		{"391", true},  /* rfc1459 RPL_TIME */
+		{"402", true},  /* rfc1459 ERR_NOSUCHSERVER */
 		{NULL, true}
 	}},
 	{"WHOWAS", {
-		{"312", false},
-		{"314", false},
-		{"369", true},
+		{"406", false},  /* rfc1459 ERR_WASNOSUCHNICK */
+		{"312", false},  /* rfc1459 RPL_WHOISSERVER */
+		{"314", false},  /* rfc1459 RPL_WHOWASUSER */
+		{"369", true},  /* rfc1459 RPL_ENDOFWHOWAS */
+		{"431", true},  /* rfc1459 ERR_NONICKNAMEGIVEN */
 		{NULL, true}
 	}},
 	{"ISON", {
-		{"303", true},
+		{"303", true},  /* rfc1459 RPL_ISON */
+		{"461", true},  /* rfc1459 ERR_NEEDMOREPARAMS */
 		{NULL, true}
 	}},
 	{"LINKS", {
-		{"364", false},
-		{"365", true},
+		{"364", false},  /* rfc1459 RPL_LINKS */
+		{"365", true},  /* rfc1459 RPL_ENDOFLINKS */
+		{"402", true},  /* rfc1459 ERR_NOSUCHSERVER */
 		{NULL, true}
 	}},
 	{"MAP", {
@@ -100,17 +112,33 @@ static const struct {
 		{"015", false},
 		{"017", true},
 		{"007", true},
+		{"481", true},  /* rfc1459 ERR_NOPRIVILEGES */
 		{NULL, true}
 	}},
 	{"TRACE", {
-		{"200", false},
-		{"205", false},
+		{"200", false},  /* rfc1459 RPL_TRACELINK */
+		{"201", false},  /* rfc1459 RPL_TRACECONNECTING */
+		{"202", false},  /* rfc1459 RPL_TRACEHANDSHAKE */
+		{"203", false},  /* rfc1459 RPL_TRACEUNKNOWN */
+		{"204", false},  /* rfc1459 RPL_TRACEOPERATOR */
+		{"205", false},  /* rfc1459 RPL_TRACEUSER */
+		{"206", false},  /* rfc1459 RPL_TRACESERVER */
+		{"208", false},  /* rfc1459 RPL_TRACENEWTYPE */
+		{"261", false},  /* rfc1459 RPL_TRACELOG */
 		{"262", true},
+		{"402", true},  /* rfc1459 ERR_NOSUCHSERVER */
 		{NULL, true}
 	}},
 	{"USERS", {
 		{"265", false},
 		{"266", true},
+		{"392", false},  /* rfc1459 RPL_USERSSTART */
+		{"393", false},  /* rfc1459 RPL_USERS */
+		{"394", true},  /* rfc1459 RPL_ENDOFUSERS */
+		{"395", false},  /* rfc1459 RPL_NOUSERS */
+		{"402", true},  /* rfc1459 ERR_NOSUCHSERVER */
+		{"424", true},  /* rfc1459 ERR_FILEERROR */
+		{"446", true},  /* rfc1459 ERR_USERSDISABLED */
 		{NULL, true},
 	}},
 	// This is just a list of all possible /mode replies stuffed together.
@@ -128,6 +156,10 @@ static const struct {
 		// MODE e
 		{"348", false},
 		{"349", true},
+		{"467", true},  /* rfc1459 ERR_KEYSET */
+		{"472", true},  /* rfc1459 ERR_UNKNOWNMODE */
+		{"501", true},  /* rfc1459 ERR_UMODEUNKNOWNFLAG */
+		{"502", true},  /* rfc1459 ERR_USERSDONTMATCH */
 		{NULL, true},
 	 }},
 	// END (last item!)
@@ -159,6 +191,10 @@ public:
 	{
 		m_pDoing = NULL;
 		m_pReplies = NULL;
+
+		AddHelpCommand();
+		AddCommand("Silent", static_cast<CModCommand::ModCmdFunc>(&CRouteRepliesMod::SilentCommand),
+			"[yes|no]");
 	}
 
 	virtual ~CRouteRepliesMod() {
@@ -251,7 +287,7 @@ public:
 	{
 		CString sCmd = sLine.Token(0).AsUpper();
 
-		if (!m_pUser->GetIRCSock())
+		if (!m_pNetwork->GetIRCSock())
 			return CONTINUE;
 
 		if (sCmd.Equals("MODE")) {
@@ -308,7 +344,7 @@ public:
 	{
 		// The timer will be deleted after this by the event loop
 
-		if (GetNV("silent_timeouts") != "yes") {
+		if (!GetNV("silent_timeouts").ToBool()) {
 			PutModule("This module hit a timeout which is possibly a bug.");
 			PutModule("To disable this message, do \"/msg " + GetModNick()
 					+ " silent yes\"");
@@ -337,7 +373,7 @@ private:
 
 		// 353 needs special treatment due to NAMESX and UHNAMES
 		if (bIsRaw353)
-			GetUser()->GetIRCSock()->ForwardRaw353(sLine, m_pDoing);
+			m_pNetwork->GetIRCSock()->ForwardRaw353(sLine, m_pDoing);
 		else
 			m_pDoing->PutClient(sLine);
 
@@ -389,27 +425,15 @@ private:
 		it->second.erase(it->second.begin());
 	}
 
-	virtual void OnModCommand(const CString& sCommand) {
-		const CString sCmd = sCommand.Token(0);
-		const CString sArgs = sCommand.Token(1, true);
+	void SilentCommand(const CString& sLine) {
+		const CString sValue = sLine.Token(1);
 
-		if (sCmd.Equals("silent")) {
-			if (sArgs.Equals("yes")) {
-				SetNV("silent_timeouts", "yes");
-				PutModule("Disabled timeout messages");
-			} else if (sArgs.Equals("no")) {
-				DelNV("silent_timeouts");
-				PutModule("Enabled timeout messages");
-			} else if (sArgs.empty()) {
-				if (GetNV("silent_timeouts") == "yes")
-					PutModule("Timeout messages are disabled");
-				else
-					PutModule("Timeout message are enabled");
-			} else
-				PutModule("Invalid argument");
-		} else {
-			PutModule("Available commands: silent [yes/no], silent");
+		if (!sValue.empty()) {
+			SetNV("silent_timeouts", sValue);
 		}
+
+		CString sPrefix = GetNV("silent_timeouts").ToBool() ? "dis" : "en";
+		PutModule("Timeout messages are " + sPrefix + "abled.");
 	}
 
 	CClient            *m_pDoing;
@@ -429,4 +453,4 @@ template<> void TModInfo<CRouteRepliesMod>(CModInfo& Info) {
 	Info.SetWikiPage("route_replies");
 }
 
-MODULEDEFS(CRouteRepliesMod, "Send replies (e.g. to /who) to the right client only")
+NETWORKMODULEDEFS(CRouteRepliesMod, "Send replies (e.g. to /who) to the right client only")
