@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -14,11 +14,15 @@
 
 #define REQUIRESSL
 
-#include "Chan.h"
-#include "User.h"
-#include "FileUtils.h"
+#include <znc/Chan.h>
+#include <znc/User.h>
+#include <znc/Buffer.h>
+#include <znc/IRCNetwork.h>
+#include <znc/FileUtils.h>
 #include <sys/stat.h>
 
+using std::vector;
+
 #define CRYPT_VERIFICATION_TOKEN "::__:SAVEBUFF:__::"
 // this is basically plain text, but so is having the pass in the command line so *shrug*
 // you could at least do something kind of cool like a bunch of unprintable text
@@ -84,10 +88,10 @@ public:
 		{
 			m_bFirstLoad = true;
 			AddTimer(new CSaveBuffJob(this, 60, 0, "SaveBuff", "Saves the current buffer to disk every 1 minute"));
-			const vector<CChan *>& vChans = m_pUser->GetChans();
+			const vector<CChan *>& vChans = m_pNetwork->GetChans();
 			for (u_int a = 0; a < vChans.size(); a++)
 			{
-				if (!vChans[a]->KeepBuffer())
+				if (vChans[a]->AutoClearChanBuffer())
 					continue;
 
 				if (!BootStrap(vChans[a]))
@@ -103,7 +107,7 @@ public:
 		CString sFile;
 		if (DecryptChannel(pChan->GetName(), sFile))
 		{
-			if (!pChan->GetBuffer().empty())
+			if (!pChan->GetBuffer().IsEmpty())
 				return(true); // reloaded a module probably in this case, so just verify we can decrypt the file
 
 			VCString vsLines;
@@ -114,7 +118,25 @@ public:
 			for (it = vsLines.begin(); it != vsLines.end(); ++it) {
 				CString sLine(*it);
 				sLine.Trim();
-				pChan->AddBuffer(sLine);
+				if (sLine[0] == '@' && it+1 != vsLines.end())
+				{
+					CString sTimestamp = sLine.Token(0);
+					sTimestamp.TrimLeft("@");
+					timeval ts;
+					ts.tv_sec = sTimestamp.Token(0, false, ",").ToLongLong();
+					ts.tv_usec = sTimestamp.Token(1, false, ",").ToLong();
+
+					CString sFormat = sLine.Token(1, true);
+
+					CString sText(*++it);
+					sText.Trim();
+
+					pChan->AddBuffer(sFormat, sText, &ts);
+				} else
+				{
+					// Old format, escape the line and use as is.
+					pChan->AddBuffer(_NAMEDFMT(sLine));
+				}
 			}
 		} else
 		{
@@ -130,24 +152,30 @@ public:
 	{
 		if (!m_sPassword.empty())
 		{
-			const vector<CChan *>& vChans = m_pUser->GetChans();
+			const vector<CChan *>& vChans = m_pNetwork->GetChans();
 			for (u_int a = 0; a < vChans.size(); a++)
 			{
 				CString sPath = GetPath(vChans[a]->GetName());
 				CFile File(sPath);
 
-				if (!vChans[a]->KeepBuffer()) {
+				if (vChans[a]->AutoClearChanBuffer()) {
 					File.Delete();
 					continue;
 				}
 
-				const vector<CString> & vBuffer = vChans[a]->GetBuffer();
+				const CBuffer& Buffer = vChans[a]->GetBuffer();
+				CString sLine;
 
 				CString sFile = CRYPT_VERIFICATION_TOKEN;
 
-				for (u_int b = 0; b < vBuffer.size(); b++)
-				{
-						sFile += vBuffer[b] + "\n";
+				size_t uSize = Buffer.Size();
+				for (unsigned int uIdx = 0; uIdx < uSize; uIdx++) {
+					const CBufLine& Line = Buffer.GetBufLine(uIdx);
+					timeval ts = Line.GetTime();
+					sFile +=
+						"@" + CString(ts.tv_sec) + "," + CString(ts.tv_usec) + " " +
+						Line.GetFormat() + "\n" +
+						Line.GetText() + "\n";
 				}
 
 				CBlowfish c(m_sPassword, BF_ENCRYPT);
@@ -245,8 +273,8 @@ public:
 
 	void AddBuffer(CChan& chan, const CString &sLine)
 	{
-		// If they have keep buffer disabled, only add messages if no client is connected
-		if (!chan.KeepBuffer() && m_pUser->IsUserAttached())
+		// If they have AutoClearChanBuffer enabled, only add messages if no client is connected
+		if (chan.AutoClearChanBuffer() && m_pNetwork->IsUserAttached())
 			return;
 		chan.AddBuffer(sLine);
 	}
@@ -257,7 +285,7 @@ public:
 	}
 	virtual void OnQuit(const CNick& cNick, const CString& sMessage, const vector<CChan*>& vChans)
 	{
-		for (u_int a = 0; a < vChans.size(); a++)
+		for (size_t a = 0; a < vChans.size(); a++)
 		{
 			AddBuffer(*vChans[a], SpoofChanMsg(vChans[a]->GetName(), cNick.GetNickMask() + " QUIT " + sMessage));
 		}
@@ -267,7 +295,7 @@ public:
 
 	virtual void OnNick(const CNick& cNick, const CString& sNewNick, const vector<CChan*>& vChans)
 	{
-		for (u_int a = 0; a < vChans.size(); a++)
+		for (size_t a = 0; a < vChans.size(); a++)
 		{
 			AddBuffer(*vChans[a], SpoofChanMsg(vChans[a]->GetName(), cNick.GetNickMask() + " NICK " + sNewNick));
 		}
@@ -337,7 +365,9 @@ void CSaveBuffJob::RunJob()
 
 template<> void TModInfo<CSaveBuff>(CModInfo& Info) {
 	Info.SetWikiPage("savebuff");
+	Info.SetHasArgs(true);
+	Info.SetArgsHelpText("This user module takes up to one arguments. Either --ask-pass or the password itself (which may contain spaces) or nothing");
 }
 
-MODULEDEFS(CSaveBuff, "Stores channel buffers to disk, encrypted")
+NETWORKMODULEDEFS(CSaveBuff, "Stores channel buffers to disk, encrypted")
 
