@@ -1,13 +1,17 @@
 /*
- * Copyright (C) 2004-2009  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "User.h"
-#include "znc.h"
+#include <znc/FileUtils.h>
+#include <znc/User.h>
+#include <znc/znc.h>
+#include <znc/ExecSock.h>
+
+using std::vector;
 
 // Forward Declaration
 class CShellMod;
@@ -35,10 +39,10 @@ public:
 	virtual void ReadLine(const CString& sData);
 	virtual void Disconnected();
 
-	CShellMod*	m_pParent;
+	CShellMod* m_pParent;
 
 private:
-	CClient*	m_pClient;
+	CClient*   m_pClient;
 };
 
 class CShellMod : public CModule {
@@ -48,7 +52,7 @@ public:
 	}
 
 	virtual ~CShellMod() {
-		vector<CZNCSock*> vSocks = m_pManager->FindSocksByName("SHELL");
+		vector<Csock*> vSocks = m_pManager->FindSocksByName("SHELL");
 
 		for (unsigned int a = 0; a < vSocks.size(); a++) {
 			m_pManager->DelSockByAddr(vSocks[a]);
@@ -83,82 +87,23 @@ public:
 			}
 
 			PutShell("znc$");
-		} else if (sCommand.Equals("SEND")) {
-			CString sToNick = sLine.Token(1);
-			CString sFile = sLine.Token(2);
-
-			if ((sToNick.empty()) || (sFile.empty())) {
-				PutShell("usage: Send <nick> <file>");
-			} else {
-				sFile = CDir::ChangeDir(m_sPath, sFile, CZNC::Get().GetHomePath());
-
-				if (!CFile::Exists(sFile)) {
-					PutShell("get: no such file [" + sFile + "]");
-				} else if (!CFile::IsReg(sFile)) {
-					PutShell("get: not a file [" + sFile + "]");
-				} else {
-					m_pUser->SendFile(sToNick, sFile, GetModName());
-				}
-			}
-		} else if (sCommand.Equals("GET")) {
-			CString sFile = sLine.Token(1);
-
-			if (sFile.empty()) {
-				PutShell("usage: Get <file>");
-			} else {
-				sFile = CDir::ChangeDir(m_sPath, sFile, CZNC::Get().GetHomePath());
-
-				if (!CFile::Exists(sFile)) {
-					PutShell("get: no such file [" + sFile + "]");
-				} else if (!CFile::IsReg(sFile)) {
-					PutShell("get: not a file [" + sFile + "]");
-				} else {
-					m_pUser->SendFile(m_pUser->GetCurNick(), sFile, GetModName());
-				}
-			}
 		} else {
 			RunCommand(sLine);
 		}
 	}
 
-	virtual EModRet OnStatusCommand(CString& sCommand) {
-		if (sCommand.Equals("SHELL")) {
-			PutShell("-- ZNC Shell Service --");
-			return HALT;
-		}
-
-		return CONTINUE;
-	}
-
-	virtual EModRet OnDCCUserSend(const CNick& RemoteNick, unsigned long uLongIP, unsigned short uPort, const CString& sFile, unsigned long uFileSize) {
-		if (RemoteNick.GetNick().Equals(GetModNick())) {
-			CString sLocalFile = CDir::ChangeDir(m_sPath, sFile, CZNC::Get().GetHomePath());
-
-			m_pUser->GetFile(m_pUser->GetCurNick(), CUtils::GetIP(uLongIP), uPort, sLocalFile, uFileSize, GetModName());
-
-			return HALT;
-		}
-
-		return CONTINUE;
-	}
-
-	void PutShell(const CString& sLine) {
-		CString sPath = m_sPath;
-
-		CString::size_type a = sPath.find(' ');
-		while (a != CString::npos) {
-			sPath.replace(a, 1, "_");
-			a = sPath.find(' ');
-		}
-
-		PutModule(sLine, "shell", sPath);
+	void PutShell(const CString& sMsg) {
+		CString sPath = m_sPath.Replace_n(" ", "_");
+		CString sSource = ":" + GetModNick() + "!shell@" + sPath;
+		CString sLine = sSource + " PRIVMSG " + m_pClient->GetNick() + " :" + sMsg;
+		m_pClient->PutClient(sLine);
 	}
 
 	void RunCommand(const CString& sCommand) {
 		m_pManager->AddSock(new CShellSock(this, m_pClient, "cd " + m_sPath + " && " + sCommand), "SHELL");
 	}
 private:
-	CString	m_sPath;
+	CString m_sPath;
 };
 
 void CShellSock::ReadLine(const CString& sData) {
@@ -184,5 +129,12 @@ void CShellSock::Disconnected() {
 	m_pParent->SetClient(NULL);
 }
 
-MODULEDEFS(CShellMod, "Gives shell access")
+template<> void TModInfo<CShellMod>(CModInfo& Info) {
+	Info.SetWikiPage("shell");
+}
 
+#ifdef MOD_SHELL_ALLOW_EVERYONE
+USERMODULEDEFS(CShellMod, "Gives shell access")
+#else
+USERMODULEDEFS(CShellMod, "Gives shell access. Only ZNC admins can use it.")
+#endif
