@@ -1,13 +1,15 @@
 /*
- * Copyright (C) 2004-2011  See the AUTHORS file for details.
+ * Copyright (C) 2004-2012  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
  * by the Free Software Foundation.
  */
 
-#include "Chan.h"
-#include "User.h"
+#include <znc/Chan.h>
+#include <znc/IRCNetwork.h>
+
+using std::vector;
 
 class CStickyChan : public CModule
 {
@@ -25,7 +27,7 @@ public:
 		{
 			if (sChannel.Equals(it->first))
 			{
-				CChan* pChan = m_pUser->FindChan(sChannel);
+				CChan* pChan = m_pNetwork->FindChan(sChannel);
 
 				if (pChan)
 				{
@@ -76,17 +78,17 @@ public:
 
 	virtual void RunJob()
 	{
-		if (!m_pUser->GetIRCSock())
+		if (!m_pNetwork->GetIRCSock())
 			return;
 
 		for (MCString::iterator it = BeginNV(); it != EndNV(); ++it)
 		{
-			CChan *pChan = m_pUser->FindChan(it->first);
+			CChan *pChan = m_pNetwork->FindChan(it->first);
 			if (!pChan) {
-				pChan = new CChan(it->first, m_pUser, true);
+				pChan = new CChan(it->first, m_pNetwork, true);
 				if (!it->second.empty())
 					pChan->SetKey(it->second);
-				if (!m_pUser->AddChan(pChan)) {
+				if (!m_pNetwork->AddChan(pChan)) {
 					/* AddChan() deleted that channel */
 					PutModule("Could not join [" + it->first
 							+ "] (# prefix missing?)");
@@ -107,7 +109,7 @@ public:
 		if (sPageName == "index") {
 			bool bSubmitted = (WebSock.GetParam("submitted").ToInt() != 0);
 
-			const vector<CChan*>& Channels = m_pUser->GetChans();
+			const vector<CChan*>& Channels = m_pNetwork->GetChans();
 			for (unsigned int c = 0; c < Channels.size(); c++) {
 				const CString sChan = Channels[c]->GetName();
 				bool bStick = FindNV(sChan) != EndNV();
@@ -189,6 +191,8 @@ bool CStickyChan::OnLoad(const CString& sArgs, CString& sMessage)
 
 template<> void TModInfo<CStickyChan>(CModInfo& Info) {
 	Info.SetWikiPage("stickychan");
+	Info.SetHasArgs(true);
+	Info.SetArgsHelpText("List of channels, separated by comma.");
 }
 
-MODULEDEFS(CStickyChan, "configless sticky chans, keeps you there very stickily even")
+NETWORKMODULEDEFS(CStickyChan, "configless sticky chans, keeps you there very stickily even")
